@@ -194,7 +194,7 @@ class Table(DataVarsSerializer):
             # get table body
             # empty value at start add for fix data transfer
             self.body = self.arrayArrayString(
-                dv.Get(varObj.name, humanreadable=True if briefmode else None))
+                dv.Get(varObj.name, humanreadable=True if briefmode else False))
         else:
             self.head = head
             self.fields = fields
@@ -490,6 +490,7 @@ class ViewParams(ClassSerializer):
     brief = Boolean  # request brief variables
     onlyhelp = Boolean  # request params for only help
     help_set = Boolean  # set cl_help_set to on
+    conargs = Array(String)  # set cl_console_args
     dispatch_usenew = Boolean  # set cl_dispatch_conf to usenew
     clienttype = String  # type of client "gui","console"
 
@@ -826,7 +827,7 @@ class TableAdapter(WsdlAdapter):
     head = WsdlAdapter.StringArray("head")
 
     @classmethod
-    def get_matrix(self, value):
+    def get_matrix(cls, value):
         if hasattr(value, 'stringArray'):
             return [row.string
                     for row in value.stringArray
